==> mingw-w64-qt6-base-6.10.0-1-any.pkg.tar.zst: usr/x86_64-w64-mingw32/include/qt6/QtCore/qconfig.h <==
#define QT_FEATURE_version_tagging 1

#define QT_FEATURE_shared 1

#define QT_FEATURE_static -1

#define QT_FEATURE_cross_compile 1

#define QT_FEATURE_pkg_config 1

#define QT_FEATURE_debug_and_release -1

#define QT_FEATURE_separate_debug_info -1

#define QT_FEATURE_appstore_compliant -1

#define QT_FEATURE_simulator_and_device -1

#define QT_FEATURE_rpath -1

#define QT_FEATURE_force_asserts -1

#define QT_FEATURE_framework -1

#define QT_FEATURE_cxx20 1

#define QT_FEATURE_cxx2a 1

#define QT_FEATURE_cxx2b -1

#define QT_FEATURE_cxx2c -1

#define QT_FEATURE_reduce_relocations -1

#define QT_FEATURE_signaling_nan 1

#define QT_FEATURE_wasm_simd128 -1

#define QT_FEATURE_wasm_exceptions -1

#define QT_FEATURE_wasm_jspi -1

#define QT_FEATURE_zstd 1

#define QT_FEATURE_thread 1

#define QT_FEATURE_future 1

#define QT_FEATURE_concurrent 1

#define QT_FEATURE_dbus 1

#define QT_FEATURE_openssl_linked -1

#define QT_FEATURE_openssl_password_digestor -1

#define QT_FEATURE_opensslv11 -1

#define QT_FEATURE_opensslv30 1

#define QT_FEATURE_test_gui 1


#define QT_VERSION_STR "6.10.0"

#define QT_VERSION_MAJOR 6

#define QT_VERSION_MINOR 10

#define QT_VERSION_PATCH 0

#define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
#define QT_LARGEFILE_SUPPORT 64
#define QT_VISIBILITY_AVAILABLE
#define QT_COMPILER_SUPPORTS_SSE2 1
#define QT_COMPILER_SUPPORTS_SSE3 1
#define QT_COMPILER_SUPPORTS_SSSE3 1
#define QT_COMPILER_SUPPORTS_SSE4_1 1
#define QT_COMPILER_SUPPORTS_SSE4_2 1
#define QT_COMPILER_SUPPORTS_AVX 1
#define QT_COMPILER_SUPPORTS_F16C 1
#define QT_COMPILER_SUPPORTS_AVX2 1
#define QT_COMPILER_SUPPORTS_AVX512F 1
#define QT_COMPILER_SUPPORTS_AVX512ER 1
#define QT_COMPILER_SUPPORTS_AVX512CD 1
#define QT_COMPILER_SUPPORTS_AVX512PF 1
#define QT_COMPILER_SUPPORTS_AVX512DQ 1
#define QT_COMPILER_SUPPORTS_AVX512BW 1
#define QT_COMPILER_SUPPORTS_AVX512VL 1
#define QT_COMPILER_SUPPORTS_AVX512IFMA 1
#define QT_COMPILER_SUPPORTS_AVX512VBMI 1
#define QT_COMPILER_SUPPORTS_AVX512VBMI2 1
#define QT_COMPILER_SUPPORTS_AES 1
#define QT_COMPILER_SUPPORTS_VAES 1
#define QT_COMPILER_SUPPORTS_RDRND 1
#define QT_COMPILER_SUPPORTS_RDSEED 1
#define QT_COMPILER_SUPPORTS_SHA 1
#define QT_GUI_TEST 1

==> mingw-w64-qt6-base-6.10.1-2-any.pkg.tar.zst: usr/x86_64-w64-mingw32/include/qt6/QtCore/qconfig.h <==
#ifndef QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_h_H
#define QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_h_H

#define QT_FEATURE_version_tagging 1

#define QT_FEATURE_shared 1

#define QT_FEATURE_static -1

#define QT_FEATURE_cross_compile 1

#define QT_FEATURE_pkg_config 1

#define QT_FEATURE_debug_and_release -1

#define QT_FEATURE_separate_debug_info -1

#define QT_FEATURE_appstore_compliant -1

#define QT_FEATURE_simulator_and_device -1

#define QT_FEATURE_rpath -1

#define QT_FEATURE_force_asserts -1

#define QT_FEATURE_framework -1

#define QT_FEATURE_cxx20 1

#define QT_FEATURE_cxx2a 1

#define QT_FEATURE_cxx2b -1

#define QT_FEATURE_cxx2c -1

#define QT_FEATURE_reduce_relocations -1

#define QT_FEATURE_signaling_nan 1

#define QT_FEATURE_wasm_simd128 -1

#define QT_FEATURE_wasm_exceptions -1

#define QT_FEATURE_wasm_jspi -1

#define QT_FEATURE_zstd 1

#define QT_FEATURE_thread 1

#define QT_FEATURE_future 1

#define QT_FEATURE_concurrent 1

#define QT_FEATURE_dbus 1

#define QT_FEATURE_openssl_linked -1

#define QT_FEATURE_openssl_password_digestor -1

#define QT_FEATURE_opensslv11 -1

#define QT_FEATURE_opensslv30 1

#define QT_FEATURE_test_gui 1


#define QT_VERSION_STR "6.10.1"

#define QT_VERSION_MAJOR 6

#define QT_VERSION_MINOR 10

#define QT_VERSION_PATCH 1

#define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
#define QT_LARGEFILE_SUPPORT 64
#define QT_VISIBILITY_AVAILABLE
#define QT_COMPILER_SUPPORTS_SSE2 1
#define QT_COMPILER_SUPPORTS_SSE3 1
#define QT_COMPILER_SUPPORTS_SSSE3 1
#define QT_COMPILER_SUPPORTS_SSE4_1 1
#define QT_COMPILER_SUPPORTS_SSE4_2 1
#define QT_COMPILER_SUPPORTS_AVX 1
#define QT_COMPILER_SUPPORTS_F16C 1
#define QT_COMPILER_SUPPORTS_AVX2 1
#define QT_COMPILER_SUPPORTS_AVX512F 1
#define QT_COMPILER_SUPPORTS_AVX512ER 1
#define QT_COMPILER_SUPPORTS_AVX512CD 1
#define QT_COMPILER_SUPPORTS_AVX512PF 1
#define QT_COMPILER_SUPPORTS_AVX512DQ 1
#define QT_COMPILER_SUPPORTS_AVX512BW 1
#define QT_COMPILER_SUPPORTS_AVX512VL 1
#define QT_COMPILER_SUPPORTS_AVX512IFMA 1
#define QT_COMPILER_SUPPORTS_AVX512VBMI 1
#define QT_COMPILER_SUPPORTS_AVX512VBMI2 1
#define QT_COMPILER_SUPPORTS_AES 1
#define QT_COMPILER_SUPPORTS_VAES 1
#define QT_COMPILER_SUPPORTS_RDRND 1
#define QT_COMPILER_SUPPORTS_RDSEED 1
#define QT_COMPILER_SUPPORTS_SHA 1
#define QT_GUI_TEST 1

#endif // QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_h_H
